<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:sqf="http://www.schematron-quickfix.com/validator/process" xmlns:tei="http://www.tei-c.org/ns/1.0">
	<ns prefix="tei" uri="http://www.tei-c.org/ns/1.0"/>
	<!--#############################-->
	<!--Qualitätskontrolle für die Rhodoman-Transkriptionen [durch DH-Stelle nach Anreicherung]-->
	<!--#############################-->
	<!--erstellt und gepflegt von Jennifer Bunselmeier (2022)-->
	<!--Filter für Einheiten, die die QMTrans-Flag haben (nicht nur die MetaQM-Flag)-->
	<let name="QMTrans" value="/tei:TEI[descendant::tei:change[@type = 'readyForQMTrans']]"/>
	<diagnostics>
		<diagnostic id="mNameE">[<value-of select="name(.)"/>]</diagnostic>
		<diagnostic id="mNameEA">[<value-of select="concat($nameE, '/@', $nameA)"/>]</diagnostic>
		<diagnostic id="mNameERef">[<value-of select="concat(name(.), '(', ./@type, ')')"/>]</diagnostic>
	</diagnostics>
	<!--......................................................-->
	<!--Regeln, die schon ab MetaQM-Flag gelten-->
	<!--......................................................-->
	<pattern id="IDREF">
		<!--geht nicht über RNG datatype=IDREF, weil IDREF nicht mit # beginnen darf-->
		<rule context="tei:*[string(@ref)][starts-with(@ref, '#')]">
			<let name="refID" value="substring-after(@ref, '#')"/>
			<assert test="exists(/tei:TEI//tei:*[@xml:id = $refID])" role="error">Es gibt kein Zielelement mit dieser ID (<value-of select="$refID"/>).</assert>
		</rule>
		<rule context="tei:*[string(@sameAs)][starts-with(@sameAs, '#')]">
			<let name="sameAsID" value="substring-after(@sameAs, '#')"/>
			<assert test="exists(/tei:TEI//tei:item[@xml:id eq $sameAsID])" role="error">Es gibt keinen Kurztitel mit der in @sameAs referenzierten ID (<value-of select="$sameAsID"/>).</assert>
		</rule>
	</pattern>
	<pattern id="hashtag">
		<rule abstract="true" id="checkForHash">
			<let name="nameA" value="name()"/>
			<let name="nameE" value="parent::tei:*/name()"/>
			<assert test="starts-with(., '#')" diagnostics="mNameEA"># fehlt.</assert>
		</rule>
		<rule context="@corresp[string()]">
			<extends rule="checkForHash"/>
		</rule>
		<rule context="@ref[string()]">
			<extends rule="checkForHash"/>
		</rule>
		<rule context="@sameAs[string()]">
			<extends rule="checkForHash"/>
		</rule>
		<rule context="@target[string()][not(parent::tei:ref[@type = 'internal'] or parent::tei:ptr[@type='verse'])]">
			<assert test="starts-with(., '#') or starts-with(., 'http')"># or http fehlt in <value-of select="parent::tei:*/name()"/>/@target.</assert>
		</rule>
	</pattern>
	<pattern id="seg-spondaic">
		<rule context="tei:seg[@type = 'spondaic']">
			<report test="tei:*[not(self::tei:seg)]" role="warn">Element (<value-of select="tei:*/name()"/>) in Spondiacus gefunden (normalerweise ist nur Text erlaubt, okay sind: rs,supplied,distinct).</report>
		</rule>
	</pattern>
	<pattern id="span">
		<rule context="$QMTrans//tei:span">
			<report test="exists(.)" role="error">Span gefunden > nicht korrekt in Note umgewandelt?</report>
		</rule>
	</pattern>
	<pattern id="front.footnote">
		<rule context="tei:front[descendant::tei:anchor or tei:span or tei:note]">
			<assert test="/tei:TEI//tei:back//tei:list[@corresp = '#front']/tei:note" role="error">Anchor, Span oder note in Front gefunden, aber keine Note im back/list[#front] kodiert.</assert>
		</rule>
	</pattern>
	<pattern id="textsprungmarke.mehrereGedichte">
		<rule context="tei:TEI[count(descendant::tei:div[@type = 'segment']) = 2]//tei:div[@type = 'contentMilestones']">
			<assert test="descendant::tei:ptr[matches(@target, '#d1\.h1\.v1')] and descendant::tei:ptr[matches(@target, '#d2\.h1\.v1')]" role="warn">Bitte prüfen: gibt es zu jedem Gedichtbeginn eine Textsprungmarke?</assert>
		</rule>
		<rule context="tei:TEI[count(descendant::tei:div[@type = 'segment']) = 3]//tei:div[@type = 'contentMilestones']">
			<assert test="descendant::tei:ptr[matches(@target, '#d1\.h1\.v1')] and descendant::tei:ptr[matches(@target, '#d2\.h1\.v1')] and descendant::tei:ptr[matches(@target, '#d3\.h1\.v1')]" role="warn">Bitte prüfen: gibt es zu jedem Gedichtbeginn eine Textsprungmarke?</assert>
		</rule>
	</pattern>
	<pattern id="title">
		<rule context="tei:title[@type = 'quoteInternal']">
			<let name="sameAsID" value="substring-after(@sameAs, '#')"/>
			<assert test="string(@sameAs)" role="error">Int. Kürzel: @sameAs fehlt oder leer.</assert>
			<assert test="starts-with(@sameAs, '#kt_')" role="error">Int. Kürzel: @sameAs muss mit "#kt_" beginnen.</assert>
		</rule>
	</pattern>
	<pattern id="refInternal">
		<rule context="tei:ref[@type = 'internal']">
			<let name="sameAs" value="@sameAs"/>
			<let name="sameAsID" value="substring-after(@sameAs, '#')"/>
			<let name="convertTargetFileToSameAsID" value="concat('kt_', substring-before(@target, 'xml'))"/>
			<let name="convertTargetFileToSameAsIDPunkt" value="concat('kt_', substring-before(@target, '.xml'))"/>
			<assert test="@target[matches(., '#d\d')]" diagnostics="mNameERef">In @target fehlt "#d[zahl]".</assert>
			<report test="not(starts-with(@target, '#')) and not(matches(@target, '\.xml'))" diagnostics="mNameERef">In @target fehlt ".xml".</report>
			<report test="starts-with(@target, '#') and not($sameAs = /tei:TEI//tei:title[@type = 'quoteInternal']/@sameAs)" diagnostics="mNameERef">Wenn @target mit # beginnt, muss @sameAs identisch sein mit dem aktuellen Datei/@sameAs.</report>
			<report test="contains(@target, '.xml') and not(/tei:TEI//tei:item[@xml:id = $convertTargetFileToSameAsID] or /tei:TEI//tei:item[@xml:id = $convertTargetFileToSameAsIDPunkt])" diagnostics="mNameERef">In @target referenzierter Kurztitel kann nicht gefunden werden.</report>
			<report test="not(matches(@target, '#d\d+$')) and not(matches(@target, '#d\d+\.g\d\.v\d+$'))" diagnostics="mNameERef">@target endet nicht auf "#d[zahl]", sondern auf Vers, aber Versformat stimmt nicht.</report>
		</rule>
	</pattern>
	<!--......................................................-->
	<!--Regeln, die erst ab TransQM-Flag gelten-->
	<!--......................................................-->
	<!--<pattern id="metDecl.segment.equal">
		<rule context="$QMTrans//tei:metDecl/tei:note/tei:list">
			<let name="countItem" value="count(tei:item)"/>
			<let name="countSegment" value="count(ancestor::tei:TEI//tei:div[@type = 'segment'])"/>
			<assert test="$countItem = $countSegment">Die Anzahl der Metrikangabensektionen entspricht nicht der Anzahl der Gedichte in der Transkription.</assert>
		</rule>
	</pattern>-->
	<pattern id="spondaic.hexameter">
		<rule context="$QMTrans//tei:div[@type = 'segment']//tei:seg[@type = 'spondaic']">
			<let name="SegId" value="ancestor::tei:div[@type = 'segment']/@xml:id"/>
			<assert test="/tei:TEI//tei:metDecl//tei:item[substring-after(@corresp, '#') = $SegId]/tei:seg[@type = 'metDeclLanguage']/tei:seg[@type = 'meter'][matches(., 'Hexameter \(hex\)')]">Spondiaci markiert, aber Metrum nicht auf "Hexameter (hex)" gesetzt.</assert>
		</rule>
	</pattern>
	<pattern id="footnotes.anchor">
		<!--zu jeder Fußnote muss es einen Anker mit der in corresp referenzierten ID geben (pro Gedicht)-->
		<rule context="$QMTrans//tei:div[@type = 'footnotes']/tei:list/tei:note">
			<let name="listCor" value="substring-after(parent::tei:list/@corresp, '#')"/>
			<let name="noteCor" value="substring-after(@corresp, '#')"/>
			<assert test="/tei:TEI//tei:div[@xml:id = $listCor]//tei:anchor[@type = 'footnote'][@xml:id = $noteCor]">Zu dieser Fußnote gibt es in der zugehörigen Div keinen Anchor.</assert>
		</rule>
	</pattern>
	<!--<pattern id="countAuszeichnungBack">
		<rule context="$QMTrans//tei:div[@type = 'segment']">
			<let name="countRs" value="count(descendant::tei:rs[@type = 'index'][parent::tei:seg[not(@xml:lang = 'de')]])"/>
			<!-\-<let name="countRs" value="count(descendant::tei:rs[@type = 'index'])"/>-\->
			<let name="countDist" value="count(descendant::tei:distinct)"/>
			<let name="countSpon" value="count(descendant::tei:seg[@type = 'spondaic'])"/>
			<let name="id" value="@xml:id"/>
			<let name="countRsPtr" value="count(/tei:TEI//tei:div[@type = 'listIndexReferences']/tei:list[substring-after(@corresp, '#') = $id]/tei:item/tei:ptr)"/>
			<let name="countDistPtr" value="count(/tei:TEI//tei:div[@type = 'listNeologisms']/tei:list[substring-after(@corresp, '#') = $id]/tei:item/tei:ptr)"/>
			<let name="countSponPtr" value="count(/tei:TEI//tei:div[@type = 'listSpondiaci']/tei:list[substring-after(@corresp, '#') = $id]/tei:item/tei:ptr)"/>
			<!-\-TODO: Im Back werden nur die Rs aus der Transkription gelistet, nicht die aus den Übersetzungen. Entweder in Kodierung ändern oder Prüfung hier verfeinern (countRS auf rs außerhalb von ger einschränken)-\->
			<assert test="$countRsPtr = $countRs">Die Anzahl der ausgezeichneten Indexreferenzen in der Transkription (<value-of select="$countRs"/>) entspricht nicht der Anzahl der Indexreferenzen im Back (=Ptr) (<value-of select="$countRsPtr"/>).</assert>
			<assert test="$countDistPtr = $countDist">Die Anzahl der ausgezeichneten Neologismen in der Transkription entspricht nicht der Anzahl der Neologismen im Back (=Ptr).</assert>
			<assert test="$countSponPtr = $countSpon">Die Anzahl der ausgezeichneten Spondiaci in der Transkription (<value-of select="$countSpon"/>) entspricht nicht der Anzahl der Spondiaci im Back (=Ptr) (<value-of select="$countSponPtr"/>).</assert>
		</rule>
	</pattern>-->
	<pattern id="countL">
		<!--letzte Verszahl = metDecl/verseCount = anzahl lg/l-->
		<rule context="$QMTrans//tei:div[@type = 'segment']/tei:lg/tei:l[last()]">
			<let name="id" value="ancestor::tei:div[@type = 'segment']/@xml:id"/>
			<let name="n" value="@n"/>
			<let name="countL" value="count(parent::tei:lg/tei:l)"/>
			<let name="verseCount" value="/tei:TEI//tei:metDecl//tei:item[substring-after(@corresp, '#') = $id]/tei:seg[@type = 'verseCount']"/>
			<assert test="$n = $countL">Letzte Versnummer (<value-of select="$n"/>) stimmt nicht mit gezählter Verszahl(header) (<value-of select="$countL"/>) überein.</assert>
			<assert test="$n = $verseCount">Letzte Versnummer (<value-of select="$n"/>) stimmt nicht mit autom. berechneter Gesamtverszahl in den Metadaten(back) (<value-of select="$verseCount"/>) überein.</assert>
		</rule>
	</pattern>
	<pattern id="metCaesuraGrc">
		<rule context="$QMTrans//tei:div[@type = 'metadataMetrics']/tei:list[tei:item[@type = 'metCaesuraPHGrc' or @type = 'metCaesuraKTTGrc' or @type = 'metCaesuraOtherGrc'][matches(., '[1-9]')]]">
			<let name="all" value="number(tei:item[@type = 'metVerse']/tei:num)"/>
			<let name="PH" value="number(tei:item[@type = 'metCaesuraPHGrc']/tei:num[@type = 'cardinal'])"/>
			<let name="KTT" value="number(tei:item[@type = 'metCaesuraKTTGrc']/tei:num[@type = 'cardinal'])"/>
			<let name="Other" value="number(tei:item[@type = 'metCaesuraOtherGrc']/tei:num[@type = 'cardinal'])"/>
			<assert test="number($PH + $KTT + $Other) = $all" role="warn">Bitte Zäsuren (gr.) prüfen: Anzahl der Gesamtverse stimmt nicht überein mit der Gesamtanzahl aller Zäsuren (PH+KTT+Rest) [<value-of select="$PH"/>+<value-of select="$KTT"/>+<value-of select="$Other"/>=<value-of select="$all"/>].</assert>
		</rule>
	</pattern>
	<pattern id="metCaesuraLat">
		<rule context="$QMTrans//tei:div[@type = 'metadataMetrics']/tei:list[tei:item[@type = 'metCaesuraPHLat' or @type = 'metCaesuraKTTLat' or @type = 'metCaesuraOtherLat'][matches(., '[1-9]')]/tei:list]">
			<let name="all" value="number(tei:item[@type = 'metVerse']/tei:num)"/>
			<let name="PH" value="number(tei:item[@type = 'metCaesuraPHLat']/tei:num[@type = 'cardinal'])"/>
			<let name="KTT" value="number(tei:item[@type = 'metCaesuraKTTLat']/tei:num[@type = 'cardinal'])"/>
			<let name="Other" value="number(tei:item[@type = 'metCaesuraOtherLat']/tei:num[@type = 'cardinal'])"/>
			<assert test="number($PH + $KTT + $Other) = $all" role="warn">Bitte Zäsuren (lat.) prüfen: Anzahl der Gesamtverse stimmt nicht überein mit der Gesamtanzahl aller Zäsuren (PH+KTT+Rest) [<value-of select="$PH"/>+<value-of select="$KTT"/>+<value-of select="$Other"/>=<value-of select="$all"/>].</assert>
		</rule>
	</pattern>
	<pattern id="pb">
		<rule context="$QMTrans//tei:pb">
			<assert test="string(@n)" role="error">In pb ist @n leer.</assert>
		</rule>
	</pattern>
	<!--<pattern id="sw">
		<rule context="$QMTrans//tei:text//tei:note/text()">
			<report test="matches(., '\[SW\]') or matches(., 'Weise') or matches(., '\[TG\]') or matches(., 'Gärtner')" role="warn">SW/TG/Weise/Gärtner gefunden > @resp nicht korrekt kodiert?</report>
		</rule>
	</pattern>-->
	<pattern id="mainText">
		<rule context="$QMTrans//tei:l">
			<report test="count(tei:seg[@type = 'mainText'][not(@function)]) &gt; 1" role="warn">Mehr als ein "mainText" in Vers vergeben.</report>
		</rule>
	</pattern>
</schema>
